#ifndef _AVR_BITS_H_
#define _AVR_BITS_H_

/** \ingroup avr_bits
    Construct an integer with a single bit set at position \c bitpos.  
*/
#define BIT(bitpos) (1<<(bitpos))

/** \ingroup avr_bits
    Set the bit located at position \c bit in variable/register \c var. 
*/
#define bit_set(var, bit) ((var) |= BIT(bit))

/** \ingroup avr_bits
    Clear the bit located at position \c bit in variable/register \c var.
*/
#define bit_clear(var, bit) ((var) &= ~BIT(bit))

/** \ingroup avr_bits
    Toggle the bit located at position \c bit in variable/register \c var.
*/
#define bit_toggle(var, bit) ((var) ^= BIT(bit))

/** \ingroup avr_bits
    Read the bit located at position \c bit in variable/register \c var.
*/
#define bit_read(var, bit) ((var) & BIT(bit))



/** \ingroup avr_bits
    Set any bits in \c mask in variable/register \c var. */
#define bit_set_mask(var, mask) ((var) |= (mask))

/** \ingroup avr_bits
    Clear any bits in \c mask in variable/register \c var. */
#define bit_clear_mask(var, mask) ((var) &= ~(mask))

/** \ingroup avr_bits
    Toggle any bits in \c mask in variable/register \c var. */
#define bit_toggle_mask(var, mask) ((var) ^= (mask))

/** \ingroup avr_bits
    Read any bits in \c mask in variable/register \c var. */
#define bit_read_mask(var, mask) ((var) & (mask))



#endif /* _AVR_BITS_H_ */
 
